summaryrefslogtreecommitdiffstats
path: root/src/removeoverlap/remove_rectangle_overlap-test.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/removeoverlap/remove_rectangle_overlap-test.cpp')
-rw-r--r--src/removeoverlap/remove_rectangle_overlap-test.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/removeoverlap/remove_rectangle_overlap-test.cpp b/src/removeoverlap/remove_rectangle_overlap-test.cpp
index 87cf4cbb0..20f5489cc 100644
--- a/src/removeoverlap/remove_rectangle_overlap-test.cpp
+++ b/src/removeoverlap/remove_rectangle_overlap-test.cpp
@@ -117,8 +117,8 @@ int main()
{
srand(time(NULL));
- /* Ensure that the program doesn't run for more than 30 seconds. */
- alarm(30);
+ /* Ensure that the program doesn't run for more than 60 seconds. */
+ alarm(60);
utest_start("removeRectangleOverlap(zero gaps)");